<?php

	/**	
	 *	Wordpress Theme 'Dylan' Functions
	 *	=================================
	 *	
	 *	@created: Phil Thompson hello@philthompson.co.uk November 2007
	 *	@edited: 23/12/2008 by Phil Thompson
	 *	
	 *	The following basic functions build on the generic WordPress functions
	 *	to give slightly improved SEO, and slightly improved accessibility and 
	 *	allowing for greater control with CSS
	 *	
	 *	Table of Contents
	 *	-----------------
	 *	register_sidebar()
	 *	dylan_title()		
	 *	dylan_body_id()		
	 *	dylan_body_class()
	 *	legacy_comment()
	 *	dylan_comments()
	 */

if ( function_exists('register_sidebar') )
    register_sidebar(array(
        'before_widget' => '<div id="%1$s" class="column widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h2 class="widgettitle">',
        'after_title' => '</h2>',
    ));
	

	/*
	dylan_title()
	
	Creates page <title> dependent on what section/page/post we're on
	*/ 
	function dylan_title(){
		// Post, page or category: show post title
		if((is_single() || is_page() || is_category() || is_search() ) && !isset($_GET['s'])) {
			$title = wp_title('',true);
		}
		// home page : show tagline
		else if (is_home()) {  
			$title = bloginfo('description'); 
		} 
		// tag
		else if(is_tag()) { 
			$title = wp_title('',true).' (Posts tagged as)'; 
		}
		// archives: add the word archives on the end
		else if (is_archive()) { 
			$title = wp_title('',true).' Archives';  
		} 
		// search
		else if(isset($_GET['s'])){
			$title = 'Search results for  &#8216;'.$_GET['s'].' &#8217;';
		}
		/*// tag
		else if(is_tag()) { 
			$title = UTW_ShowCurrentTagSet('tagsettextonly'); 
		}*/
		
		return $title;
	}
	
	/*
	dylan_body_id()
	
	Creates an id for the <body> tag that could be used for user stylesheets
	should look like this <body id="www-example-com">
	*/ 
	function dylan_body_id(){
		$url = str_replace(array('http://','/',':8888',':80',':8080'),'',get_option('home'));
		return str_replace('.','-',$url);
	}
	
	/*
	dylan_body_class()
	
	Creates a class for the <body> tag that could be used to apply different styles for different sections
	should look like this <body class="posts"> or <body class="archives">
	*/ 
	function dylan_body_class(){
		// Post, page or category: show post title
		if(is_single()) {
			$body_class = 'post';
		}
		// category
		else if (is_category()) {  
			$body_class = 'category';
		}
		// page
		else if (is_page()) {  
			$body_class = 'page';
		} 
		// home page
		else if (is_home()) {  
			$body_class = 'home';
		} 
		// tags
		else if (is_tag()) { 
			$body_class = 'tags';  
		} 
		// archives
		else if (is_archive()) { 
			$body_class = 'archives';  
		} 
		// search
		else if(isset($_GET['s'])){
			$body_class = 'search';
		}
		
		return $body_class;
	}

/**
 * legacy_comments()
 * if WP 2.7's new comemnt style isn't available we'll
 * use the old style
 */
add_filter( 'comments_template', 'legacy_comments' );
function legacy_comments( $file ) {
	if ( !function_exists('wp_list_comments') )
		$file = TEMPLATEPATH . '/legacy.comments.php';
	return $file;
}

// add a microid to all the comments
function comment_add_microid($classes) {
	$c_email=get_comment_author_email();
	$c_url=get_comment_author_url();
	if (!empty($c_email) && !empty($c_url)) {
		$microid = 'microid-mailto+http:sha1:' . sha1(sha1('mailto:'.$c_email).sha1($c_url));
		$classes[] = $microid;
	}
	return $classes;
}
add_filter('comment_class','comment_add_microid');

function dylan_comment($comment, $args, $depth) {
   $GLOBALS['comment'] = $comment; ?>
   <li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>">
     <div id="div-comment-<?php comment_ID(); ?>">
      <div class="commenter">
            <div class="comment-author vcard">
               <?php echo get_avatar($comment,$size='48',$default='<path_to_url>' ); ?>
               <?php printf(__('<cite class="fn">%s</cite> <span class="says">says:</span>'), get_comment_author_link()) ?>
            </div>
            <?php if ($comment->comment_approved == '0') : ?>
               <em><?php _e('Your comment is awaiting moderation.') ?></em>
               <br />
            <?php endif; ?>
      <div class="comment-meta commentmetadata"><a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ) ?>"><?php printf(__('%1$s at %2$s'), get_comment_date(),  get_comment_time()) ?></a><?php edit_comment_link(__('(Edit)'),'  ','') ?></div>
      </div>
      <div class="comment">
            <?php comment_text() ?>
      </div>
      <div class="reply">
         <?php comment_reply_link(array_merge( $args, array('add_below' => 'div-comment', 'depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
      </div>
  </div>
<?php
        }

	
?>